==> causeway-bom-2.1.0-source-release.zip: causeway-bom-2.1.0/persistence/jpa/eclipselink/src/main/java/module-info.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
module org.apache.causeway.persistence.jpa.eclipselink {
    exports org.apache.causeway.persistence.jpa.eclipselink.inject;
    exports org.apache.causeway.persistence.jpa.eclipselink;
    exports org.apache.causeway.persistence.jpa.eclipselink.config;

    requires jakarta.el.api;
    requires jakarta.enterprise.cdi.api;
    requires java.annotation;
    requires java.inject;
    requires java.persistence;
    requires java.sql;
    requires lombok;
    requires org.apache.causeway.applib;
    requires org.apache.causeway.commons;
    requires org.apache.causeway.core.config;
    requires org.apache.causeway.persistence.jpa.integration;
    requires org.apache.logging.log4j;
    requires org.eclipse.persistence.core;
    requires spring.beans;
    requires spring.boot;
    requires spring.boot.autoconfigure;
    requires spring.context;
    requires spring.core;
    requires spring.jdbc;
    requires spring.orm;
    requires spring.tx;
}

==> causeway-bom-3.1.0-source-release.zip: causeway-bom-3.1.0/persistence/jpa/eclipselink/src/main/java/module-info.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */
module org.apache.causeway.persistence.jpa.eclipselink {
    exports org.apache.causeway.persistence.jpa.eclipselink.inject;
    exports org.apache.causeway.persistence.jpa.eclipselink;
    exports org.apache.causeway.persistence.jpa.eclipselink.config;

    requires jakarta.annotation;
    requires jakarta.inject;
    requires jakarta.persistence;
    requires java.sql;
    requires lombok;
    requires org.apache.causeway.applib;
    requires org.apache.causeway.commons;
    requires org.apache.causeway.core.config;
    requires org.apache.causeway.persistence.jpa.integration;
    requires org.apache.logging.log4j;
    requires org.eclipse.persistence.core;
    requires spring.beans;
    requires spring.boot;
    requires spring.boot.autoconfigure;
    requires spring.context;
    requires spring.core;
    requires spring.jdbc;
    requires spring.orm;
    requires spring.tx;
    requires jakarta.cdi;
    requires jakarta.el;
}
